# ngx-lib

ngx-lib is an Angular 5+ library providing foundational functionality to Cleaveland/Price applications.
Use of the library requires some simple configuration of the module(s) that you plan to consume in your application.

## Installation

To install this library, run:

```bash
$ npm install @cleavelandprice/ngx-lib --save
```

## Consuming ngx-lib

After installing ngx-lib, import the module(s) that you need in your `AppModule` file:

```typescript
import { BrowserModule } from '@angular/platform-browser';
import { HttpClientModule } from '@angular/common/http'; // Required by ngx-lib modules that call web services
import { NgModule } from '@angular/core';
import { AppComponent } from './app.component';

// Cleaveland/Price modules
import { EmailModule } from '@cleavelandprice/ngx-lib';

// Define the base URL for C/P API endpoints
// Definining this prefix here makes it easier to define the module-specific Urls
// i.e. The Email module will utilize a different endpoint than the SharePoint module
const webServices = 'http://SomeServer/api';

// Define a configuration for the Email module
const emailConfig = {
  serviceUrl: `${webServices}/email`, // See... now I can prefix them all with ${webServices}
  server: 'EmailServerAddress',
  smtpPort: 25,
  sender: {
    displayName: 'IT Application Process',
    emailAddress: 'address@domain.com',
    userName: 'emailuser',
    password: 'emailpassword'
  }
};

@NgModule({
  declarations: [
    AppComponent
  ],
  imports: [
    BrowserModule,

    // Import the Email module and pass in the configuration that we defined above
    // At this point, all of the functionality exported by EmailModule will be available throughout this app
    // This includes services, components, pipes, classes, etc.
    EmailModule.forRoot(emailConfig)
  ],
  providers: [],
  bootstrap: [AppComponent]
})
export class AppModule { }
```

Once modules are imported, you can use their components, directives, services, and pipes in your Angular application:

```xml
<!-- app.component.html -->
<h1>
  {{ title }}
</h1>
<cp-footer></cp-footer>
```

### Using a service
```typescript
import { Component, OnInit } from '@angular/core';

// Import some stuff provided by EmailModule
import { EmailService, Email } from '@cleavelandprice/ngx-lib';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit {
  // Inject the EmailService into this component
  constructor(private emailService: EmailService) { }

  ngOnInit(): void {
    // Define an email object
    const email: Email = {
      subject: 'Test Email',
      recipients: {
        to: ['recipient@domain.com']
      },
      content: { html: '<html><body>hooray!</body></html>' }
    };

    // Send the email
    this.emailService.send(email).subscribe();
  }
}
```

## License

MIT © [Dan Rullo](mailto:drullo@cleavelandprice.com)

This project was built using the <a href="https://github.com/qurt/generator-angular4-library">generator-angular4-library</a> project as a foundation.
