import core, { Component, EventEmitter, Inject, Injectable, Input, NgModule, Optional, Output, Pipe, SkipSelf } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatButtonModule, MatCheckboxModule, MatDialog, MatDialogModule, MatDialogRef, MatInputModule, MatProgressBarModule, MatProgressSpinnerModule, MatSelectModule, MatTooltipModule } from '@angular/material';
import { HttpClient } from '@angular/common/http';
import http$1 from '@angular/http';
import Observable, { Observable as Observable$1 } from 'rxjs/Observable';
import fromPromise from 'rxjs/add/observable/fromPromise';
import defer from 'rxjs/add/observable/defer';
import mergeMap from 'rxjs/add/operator/mergeMap';
import 'rxjs/add/observable/of';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$1 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
let DialogComponent = class DialogComponent {
    constructor() {
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
        this.mode = ConfirmationDialogMode.OkCancel;
    }
    ngOnInit() {
        if (this.data) {
            this.title = this.data.title || null;
            this.message = this.data.message || null;
            this.checkboxMessage = this.data.checkboxMessage || null;
            this.placeholder = this.data.placeholder || null;
            this.mode = this.data.mode || ConfirmationDialogMode.OkCancel;
        }
    }
    close() {
        let data;
        switch (this.dialogType) {
            case 'message':
                data = this.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case 'input':
                data = this.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case 'confirmation':
                data = this.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    }
    cancel() {
        let data;
        if (this.dialogType === 'confirmation') {
            data = this.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    }
};
__decorate$2([
    Input(),
    __metadata$1("design:type", String)
], DialogComponent.prototype, "dialogType", void 0);
__decorate$2([
    Input(),
    __metadata$1("design:type", Object)
], DialogComponent.prototype, "data", void 0);
__decorate$2([
    Output(),
    __metadata$1("design:type", Object)
], DialogComponent.prototype, "closed", void 0);
DialogComponent = __decorate$2([
    Component({
        selector: 'cp-dialog',
        template: `
      <h2 *ngIf="title" mat-dialog-title [innerHTML]="title"></h2>

      <mat-dialog-content>
          <div *ngIf="message" [innerHTML]="message"></div>

          <mat-form-field *ngIf="dialogType === 'input'">
              <textarea matInput [placeholder]="placeholder" [(ngModel)]="userInput"></textarea>
          </mat-form-field>

          <div id="checkbox" *ngIf="checkboxMessage">
              <mat-checkbox [(ngModel)]="checkboxValue">
                  <span [innerHTML]="checkboxMessage"></span>
              </mat-checkbox>
          </div>
      </mat-dialog-content>

      <mat-dialog-actions>
          <button mat-raised-button (click)="close()" [disabled]="dialogType === 'input' && !userInput">
              <span [ngSwitch]="mode">
                  <span *ngSwitchCase="ConfirmationDialogMode.YesNo">Yes</span>
                  <span *ngSwitchCase="ConfirmationDialogMode.TrueFalse">True</span>
                  <span *ngSwitchDefault>OK</span>
              </span>
          </button>
          <button *ngIf="dialogType !== 'message'" mat-raised-button (click)="cancel()">
              <span [ngSwitch]="mode">
                  <span *ngSwitchCase="ConfirmationDialogMode.YesNo">No</span>
                  <span *ngSwitchCase="ConfirmationDialogMode.TrueFalse">False</span>
                  <span *ngSwitchDefault>Cancel</span>
              </span>
          </button>
      </mat-dialog-actions>
    `,
        styles: [`
      mat-form-field {
          margin-top: 2em;
          width: 100%;
      }

      #checkbox {
          margin: 2em 0;
      }
    `]
    })
], DialogComponent);

var __decorate$3 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$2 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$1 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
let ConfirmationDialogComponent = class ConfirmationDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
ConfirmationDialogComponent = __decorate$3([
    Component({
        selector: 'cp-confirmation-dialog',
        template: `
    <cp-dialog
      [data]="data"
      [dialogType]="'confirmation'"
      (closed)="dialogRef.close($event)">
    </cp-dialog>
  `
    }),
    __param$1(1, Inject(MAT_DIALOG_DATA)),
    __metadata$2("design:paramtypes", [MatDialogRef, Object])
], ConfirmationDialogComponent);

var __decorate$4 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$3 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$2 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
let InputDialogComponent = class InputDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
InputDialogComponent = __decorate$4([
    Component({
        selector: 'cp-input-dialog',
        template: `
      <cp-dialog
        [data]="data"
        [dialogType]="'input'"
        (closed)="dialogRef.close($event)">
      </cp-dialog>
    `
    }),
    __param$2(1, Inject(MAT_DIALOG_DATA)),
    __metadata$3("design:paramtypes", [MatDialogRef, Object])
], InputDialogComponent);

var __decorate$5 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$4 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$3 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
let MessageDialogComponent = class MessageDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
MessageDialogComponent = __decorate$5([
    Component({
        selector: 'cp-message-dialog',
        template: `
      <cp-dialog
        [data]="data"
        [dialogType]="'message'"
        (closed)="dialogRef.close($event)">
      </cp-dialog>
    `
    }),
    __param$3(1, Inject(MAT_DIALOG_DATA)),
    __metadata$4("design:paramtypes", [MatDialogRef, Object])
], MessageDialogComponent);

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
//#region Imports
// Components
//#endregion
let DialogModule = class DialogModule {
};
DialogModule = __decorate$1([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatInputModule,
            MatDialogModule
        ],
        declarations: [
            DialogComponent,
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        exports: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        entryComponents: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ]
    })
], DialogModule);

class AuthenticationServiceConfig {
}

var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var __extends = (commonjsGlobal && commonjsGlobal.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var __decorate$7 = (commonjsGlobal && commonjsGlobal.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$6 = (commonjsGlobal && commonjsGlobal.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$5 = (commonjsGlobal && commonjsGlobal.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};






var AuthConfigConsts = (function () {
    function AuthConfigConsts() {
    }
    return AuthConfigConsts;
}());
AuthConfigConsts.DEFAULT_TOKEN_NAME = 'token';
AuthConfigConsts.DEFAULT_HEADER_NAME = 'Authorization';
AuthConfigConsts.HEADER_PREFIX_BEARER = 'Bearer ';
var AuthConfigDefaults = {
    headerName: AuthConfigConsts.DEFAULT_HEADER_NAME,
    headerPrefix: null,
    tokenName: AuthConfigConsts.DEFAULT_TOKEN_NAME,
    tokenGetter: function () { return localStorage.getItem(AuthConfigDefaults.tokenName); },
    noJwtError: false,
    noClientCheck: false,
    globalHeaders: [],
    noTokenScheme: false
};
/**
 * Sets up the authentication configuration.
 */
var AuthConfig = (function () {
    function AuthConfig(config) {
        config = config || {};
        this._config = objectAssign({}, AuthConfigDefaults, config);
        if (this._config.headerPrefix) {
            this._config.headerPrefix += ' ';
        }
        else if (this._config.noTokenScheme) {
            this._config.headerPrefix = '';
        }
        else {
            this._config.headerPrefix = AuthConfigConsts.HEADER_PREFIX_BEARER;
        }
        if (config.tokenName && !config.tokenGetter) {
            this._config.tokenGetter = function () { return localStorage.getItem(config.tokenName); };
        }
    }
    AuthConfig.prototype.getConfig = function () {
        return this._config;
    };
    return AuthConfig;
}());
var AuthHttpError = (function (_super) {
    __extends(AuthHttpError, _super);
    function AuthHttpError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return AuthHttpError;
}(Error));
/**
 * Allows for explicit authenticated HTTP requests.
 */
var AuthHttp = (function () {
    function AuthHttp(options, http$$1, defOpts) {
        var _this = this;
        this.http = http$$1;
        this.defOpts = defOpts;
        this.config = options.getConfig();
        this.tokenStream = new Observable.Observable(function (obs) {
            obs.next(_this.config.tokenGetter());
        });
    }
    AuthHttp.prototype.mergeOptions = function (providedOpts, defaultOpts) {
        var newOptions = defaultOpts || new http$1.RequestOptions();
        if (this.config.globalHeaders) {
            this.setGlobalHeaders(this.config.globalHeaders, providedOpts);
        }
        newOptions = newOptions.merge(new http$1.RequestOptions(providedOpts));
        return newOptions;
    };
    AuthHttp.prototype.requestHelper = function (requestArgs, additionalOptions) {
        var options = new http$1.RequestOptions(requestArgs);
        if (additionalOptions) {
            options = options.merge(additionalOptions);
        }
        return this.request(new http$1.Request(this.mergeOptions(options, this.defOpts)));
    };
    AuthHttp.prototype.requestWithToken = function (req, token) {
        if (!this.config.noClientCheck && !tokenNotExpired(undefined, token)) {
            if (!this.config.noJwtError) {
                return new Observable.Observable(function (obs) {
                    obs.error(new AuthHttpError('No JWT present or has expired'));
                });
            }
        }
        else {
            req.headers.set(this.config.headerName, this.config.headerPrefix + token);
        }
        return this.http.request(req);
    };
    AuthHttp.prototype.setGlobalHeaders = function (headers, request) {
        if (!request.headers) {
            request.headers = new http$1.Headers();
        }
        headers.forEach(function (header) {
            var key = Object.keys(header)[0];
            var headerValue = header[key];
            request.headers.set(key, headerValue);
        });
    };
    AuthHttp.prototype.request = function (url, options) {
        var _this = this;
        if (typeof url === 'string') {
            return this.get(url, options); // Recursion: transform url from String to Request
        }
        // else if ( ! url instanceof Request ) {
        //   throw new Error('First argument must be a url string or Request instance.');
        // }
        // from this point url is always an instance of Request;
        var req = url;
        // Create a cold observable and load the token just in time
        return Observable.Observable.defer(function () {
            var token = _this.config.tokenGetter();
            if (token instanceof Promise) {
                return Observable.Observable.fromPromise(token).mergeMap(function (jwtToken) { return _this.requestWithToken(req, jwtToken); });
            }
            else {
                return _this.requestWithToken(req, token);
            }
        });
    };
    AuthHttp.prototype.get = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Get, url: url }, options);
    };
    AuthHttp.prototype.post = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Post, url: url }, options);
    };
    AuthHttp.prototype.put = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Put, url: url }, options);
    };
    AuthHttp.prototype.delete = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Delete, url: url }, options);
    };
    AuthHttp.prototype.patch = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Patch, url: url }, options);
    };
    AuthHttp.prototype.head = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Head, url: url }, options);
    };
    AuthHttp.prototype.options = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Options, url: url }, options);
    };
    return AuthHttp;
}());
AuthHttp = __decorate$7([
    core.Injectable(),
    __metadata$6("design:paramtypes", [AuthConfig, http$1.Http, http$1.RequestOptions])
], AuthHttp);
/**
 * Helper class to decode and find JWT expiration.
 */
var JwtHelper = (function () {
    function JwtHelper() {
    }
    JwtHelper.prototype.urlBase64Decode = function (str) {
        var output = str.replace(/-/g, '+').replace(/_/g, '/');
        switch (output.length % 4) {
            case 0: {
                break;
            }
            case 2: {
                output += '==';
                break;
            }
            case 3: {
                output += '=';
                break;
            }
            default: {
                throw 'Illegal base64url string!';
            }
        }
        return this.b64DecodeUnicode(output);
    };
    // credits for decoder goes to https://github.com/atk
    JwtHelper.prototype.b64decode = function (str) {
        var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
        var output = '';
        str = String(str).replace(/=+$/, '');
        if (str.length % 4 == 1) {
            throw new Error("'atob' failed: The string to be decoded is not correctly encoded.");
        }
        for (
        // initialize result and counters
        var bc = 0, bs = void 0, buffer = void 0, idx = 0; 
        // get next character
        buffer = str.charAt(idx++); 
        // character found in table? initialize bit storage and add its ascii value;
        ~buffer && (bs = bc % 4 ? bs * 64 + buffer : buffer, bc++ % 4) ? output += String.fromCharCode(255 & bs >> (-2 * bc & 6)) : 0) {
            // try to find character in table (0-63, not found => -1)
            buffer = chars.indexOf(buffer);
        }
        return output;
    };
    // https://developer.mozilla.org/en/docs/Web/API/WindowBase64/Base64_encoding_and_decoding#The_Unicode_Problem
    JwtHelper.prototype.b64DecodeUnicode = function (str) {
        return decodeURIComponent(Array.prototype.map.call(this.b64decode(str), function (c) {
            return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
        }).join(''));
    };
    JwtHelper.prototype.decodeToken = function (token) {
        var parts = token.split('.');
        if (parts.length !== 3) {
            throw new Error('JWT must have 3 parts');
        }
        var decoded = this.urlBase64Decode(parts[1]);
        if (!decoded) {
            throw new Error('Cannot decode the token');
        }
        return JSON.parse(decoded);
    };
    JwtHelper.prototype.getTokenExpirationDate = function (token) {
        var decoded;
        decoded = this.decodeToken(token);
        if (!decoded.hasOwnProperty('exp')) {
            return null;
        }
        var date = new Date(0); // The 0 here is the key, which sets the date to the epoch
        date.setUTCSeconds(decoded.exp);
        return date;
    };
    JwtHelper.prototype.isTokenExpired = function (token, offsetSeconds) {
        var date = this.getTokenExpirationDate(token);
        offsetSeconds = offsetSeconds || 0;
        if (date == null) {
            return false;
        }
        // Token expired?
        return !(date.valueOf() > (new Date().valueOf() + (offsetSeconds * 1000)));
    };
    return JwtHelper;
}());
var JwtHelper_1 = JwtHelper;
/**
 * Checks for presence of token and that token hasn't expired.
 * For use with the @CanActivate router decorator and NgIf
 */
function tokenNotExpired(tokenName, jwt) {
    if (tokenName === void 0) { tokenName = AuthConfigConsts.DEFAULT_TOKEN_NAME; }
    var token = jwt || localStorage.getItem(tokenName);
    var jwtHelper = new JwtHelper();
    return token != null && !jwtHelper.isTokenExpired(token);
}
var AUTH_PROVIDERS = [
    {
        provide: AuthHttp,
        deps: [http$1.Http, http$1.RequestOptions],
        useFactory: function (http$$1, options) {
            return new AuthHttp(new AuthConfig(), http$$1, options);
        }
    }
];
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;
function toObject(val) {
    if (val === null || val === undefined) {
        throw new TypeError('Object.assign cannot be called with null or undefined');
    }
    return Object(val);
}
function objectAssign(target) {
    var source = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        source[_i - 1] = arguments[_i];
    }
    var from;
    var to = toObject(target);
    var symbols;
    for (var s = 1; s < arguments.length; s++) {
        from = Object(arguments[s]);
        for (var key in from) {
            if (hasOwnProperty.call(from, key)) {
                to[key] = from[key];
            }
        }
        if (Object.getOwnPropertySymbols) {
            symbols = Object.getOwnPropertySymbols(from);
            for (var i = 0; i < symbols.length; i++) {
                if (propIsEnumerable.call(from, symbols[i])) {
                    to[symbols[i]] = from[symbols[i]];
                }
            }
        }
    }
    return to;
}
/**
 * Module for angular2-jwt
 * @experimental
 */
var AuthModule = AuthModule_1 = (function () {
    function AuthModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthModule is already loaded. Import it in the AppModule only');
        }
    }
    AuthModule.forRoot = function (config) {
        return {
            ngModule: AuthModule_1,
            providers: [
                { provide: AuthConfig, useValue: config }
            ]
        };
    };
    return AuthModule;
}());
AuthModule = AuthModule_1 = __decorate$7([
    core.NgModule({
        imports: [http$1.HttpModule],
        providers: [AuthHttp, JwtHelper]
    }),
    __param$5(0, core.Optional()), __param$5(0, core.SkipSelf()),
    __metadata$6("design:paramtypes", [AuthModule])
], AuthModule);
var AuthModule_1;

class SharePointServiceConfig {
}

var __decorate$8 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$7 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$6 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
//#endregion
let SharePointService = class SharePointService {
    //#endregion
    constructor(config, http$$1) {
        this.http = http$$1;
        this.sharePointApiUrl = config.sharePointApiUrl;
    }
    //#region Utilities
    getListItems(list) {
        return this.http.post(this.sharePointApiUrl, list);
    }
    getListItemsSimple(list, view, site, limit) {
        return this.http.get(`${this.sharePointApiUrl}/${list}/${view}/${site}/${limit}`);
    }
    getPeople(storePeople) {
        // Do we already have people stored locally?
        if (this.people) {
            return Observable$1.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(`${this.sharePointApiUrl}/people`)
                .subscribe(peeps => this.people = peeps);
        }
        return this.http.get(`${this.sharePointApiUrl}/people`);
    }
    getPhotos(storePhotos) {
        // Do we already have photos stored locally?
        if (this.photos) {
            return Observable$1.of(this.photos);
        }
        const spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay'
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.sharePointApiUrl, spList)
                .subscribe(photos => this.photos = photos);
        }
        return this.http.post(this.sharePointApiUrl, spList);
    }
    getCustomerVisits() {
        const list = {
            list: 'Customer Visits',
            view: 'All Events'
        };
        return this.http.post(this.sharePointApiUrl, list);
    }
};
SharePointService = __decorate$8([
    Injectable(),
    __param$6(0, Optional()),
    __metadata$7("design:paramtypes", [SharePointServiceConfig,
        HttpClient])
], SharePointService);

var __decorate$6 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$5 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$4 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
//#endregion
let AuthenticationService = class AuthenticationService {
    //#endregion
    //#region Lifecycle
    constructor(config, http$$1, sharePointService) {
        this.http = http$$1;
        this.sharePointService = sharePointService;
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        this.authenticating = false;
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    login(username, password, adminGroup) {
        const today = new Date();
        const expiration = new Date().setFullYear(today.getFullYear() + 10);
        const request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(token => this.validateUser(token), err => {
            this.authenticating = false;
            this.authenticatingChanged.emit(this.authenticating);
        });
    }
    logout() {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    }
    validateUser(token) {
        if (!token) {
            return;
        }
        const jwtHelper = new JwtHelper_1();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem('token', token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    getPhoto() {
        this.sharePointService.getPhotos()
            .subscribe(photos => {
            // The user may have been logged out by the time the photos came back
            if (!this.authenticatedUser || !this.authenticatedUser.employeeNumber) {
                return;
            }
            const photo = photos.find(pic => +pic.ows_EmployeeNumber === +this.authenticatedUser.employeeNumber);
            if (photo) {
                this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    }
    checkForExistingToken() {
        if (localStorage.getItem('token')) {
            this.validateUser(localStorage.getItem('token'));
        }
    }
};
__decorate$6([
    Output(),
    __metadata$5("design:type", Object)
], AuthenticationService.prototype, "authenticatedChanged", void 0);
__decorate$6([
    Output(),
    __metadata$5("design:type", Object)
], AuthenticationService.prototype, "authenticatingChanged", void 0);
AuthenticationService = __decorate$6([
    Injectable(),
    __param$4(0, Optional()),
    __metadata$5("design:paramtypes", [AuthenticationServiceConfig,
        HttpClient,
        SharePointService])
], AuthenticationService);

var __decorate$10 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$9 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
let LoginFormComponent = class LoginFormComponent {
    constructor(dialogRef, sharePointService, authenticationService) {
        this.dialogRef = dialogRef;
        this.sharePointService = sharePointService;
        this.authenticationService = authenticationService;
    }
    ngOnInit() {
        this.authenticationService.authenticatedChanged
            .subscribe(authenticated => {
            if (authenticated) {
                this.dialogRef.close();
            }
        });
    }
    authenticate() {
        if (!this.sharePointService || !this.username || !this.password) {
            return;
        }
        this.authenticationService.login(this.username, this.password);
    }
};
LoginFormComponent = __decorate$10([
    Component({
        selector: 'cp-login-form',
        template: `
    <h2 mat-dialog-title>
      <span *ngIf="!authenticationService.authenticating">Login</span>
      <span *ngIf="authenticationService.authenticating">Authenticating...</span>
    </h2>

    <mat-dialog-content [class.loginError]="loginError">
      <div id="spinner" *ngIf="authenticationService.authenticating">
        <mat-progress-spinner color="primary" mode="indeterminate"></mat-progress-spinner>
      </div>

      <div *ngIf="!authenticationService.authenticating">
        <div>
          <mat-form-field>
            <input matInput placeholder="Username" [(ngModel)]="username" name="username" required (keyup.enter)="authenticate()">
          </mat-form-field>
        </div>

        <div>
          <mat-form-field>
            <input matInput type="password" placeholder="Password" [(ngModel)]="password" name="password" required (keyup.enter)="authenticate()">
          </mat-form-field>
        </div>
      </div>

      <div *ngIf="!authenticationService.authenticating && loginError" class="alert alert-danger">
        Bad username or password
      </div>
    </mat-dialog-content>

    <mat-dialog-actions *ngIf="!authenticationService.authenticating">
      <button type="button" mat-raised-button (click)="authenticate()">OK</button>
      <button type="button" mat-button (click)="dialogRef.close()">Cancel</button>
    </mat-dialog-actions>
  `,
        styles: [`
    #spinner {
        width: 100%;
        height: 100%;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-pack: center;
            -ms-flex-pack: center;
                justify-content: center;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center;
    }

    mat-dialog-content {
        height: 150px;
    }

    mat-dialog-content.loginError {
        height: 200px;
    }
  `]
    }),
    __metadata$9("design:paramtypes", [MatDialogRef,
        SharePointService,
        AuthenticationService])
], LoginFormComponent);

var __decorate$9 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$8 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
let LoginComponent = class LoginComponent {
    constructor(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    ngOnInit() {
    }
    login() {
        this.dialog.open(LoginFormComponent);
    }
    confirmLogout() {
        const dialogRef = this.dialog.open(ConfirmationDialogComponent, {
            data: { message: `Are you sure you want to logout?` }
        });
        dialogRef.afterClosed().subscribe(result => {
            if (result) {
                this.authenticationService.logout();
            }
        });
    }
};
LoginComponent = __decorate$9([
    Component({
        selector: 'cp-login',
        template: `
    <div id="user-id">
      <i id="unauthenticated-user-image" *ngIf="!authenticationService.authenticated"
        class="fa fa-user-circle"
        [class.fa-spin]="authenticationService.authenticating"
        aria-hidden="true"
        title="Login"
        (click)="login()"></i>

      <img id="authenticated-user-image" *ngIf="authenticationService.authenticated && authenticationService.authenticatedUser.photoUrl"
        [src]="authenticationService.authenticatedUser.photoUrl"
        title="Logout"
        (click)="confirmLogout()" />

      <div id="user-name" *ngIf="authenticationService.authenticated">
        {{ authenticationService.authenticatedUser.displayName }}
      </div>
    </div>
  `,
        styles: [`
    #user-id {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        height: 2em;
        padding: .3em;
        font-family: Verdana, Geneva, Tahoma, sans-serif;
    }

    .fa {
        font-size: 2em;
    }

    img {
        border-radius: 100%;
        width: 2em;
        height: 2em;
    }

    #user-id > div {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center;
        height: 100%;
        margin-left: .75em;
        font-size: 1.15em;
    }
  `]
    }),
    __metadata$8("design:paramtypes", [MatDialog,
        AuthenticationService])
], LoginComponent);

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
// Modules
// Services
// Components
//#endregion
let AuthenticationModule = AuthenticationModule_1 = class AuthenticationModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(authenticationConfig) {
        return {
            ngModule: AuthenticationModule_1,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    }
};
AuthenticationModule = AuthenticationModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatInputModule,
            MatProgressBarModule,
            MatProgressSpinnerModule,
            MatTooltipModule,
            MatSelectModule,
            DialogModule
        ],
        declarations: [
            LoginComponent,
            LoginFormComponent
        ],
        exports: [
            LoginComponent,
            LoginFormComponent
        ],
        providers: [],
        entryComponents: [
            LoginFormComponent
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf()),
    __metadata("design:paramtypes", [AuthenticationModule])
], AuthenticationModule);
var AuthenticationModule_1;

class EmailServiceConfig {
}

var __decorate$12 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$11 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$8 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
//#endregion
let EmailService = class EmailService {
    constructor(config, http$$1) {
        this.http = http$$1;
        this.emailServiceConfig = config;
    }
    send(email) {
        const dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    }
};
EmailService = __decorate$12([
    Injectable(),
    __param$8(0, Optional()),
    __metadata$11("design:paramtypes", [EmailServiceConfig,
        HttpClient])
], EmailService);

var __decorate$11 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$10 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$7 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
// Services
//#endregion
let EmailModule = EmailModule_1 = class EmailModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(emailConfig) {
        return {
            ngModule: EmailModule_1,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    }
};
EmailModule = EmailModule_1 = __decorate$11([
    NgModule({
        imports: [CommonModule],
        declarations: [],
        exports: []
    }),
    __param$7(0, Optional()), __param$7(0, SkipSelf()),
    __metadata$10("design:paramtypes", [EmailModule])
], EmailModule);
var EmailModule_1;

class EmployeeServiceConfig {
}

var __decorate$14 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$13 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$10 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
//#endregion
let EmployeeService = class EmployeeService {
    //#endregion
    //#region Lifecycle
    constructor(config, http$$1) {
        this.http = http$$1;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    getEmployees(storeEmployees) {
        // Do we already have employees stored locally?
        if (this.employees) {
            return Observable$1.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(this.employeeApiUrl)
                .subscribe(emps => this.employees = emps);
        }
        return this.http.get(this.employeeApiUrl);
    }
    getEmployee(sAMAccountName) {
        return this.http.get(`${this.employeeApiUrl}/name/${sAMAccountName}`);
    }
};
EmployeeService = __decorate$14([
    Injectable(),
    __param$10(0, Optional()),
    __metadata$13("design:paramtypes", [EmployeeServiceConfig,
        HttpClient])
], EmployeeService);

var __decorate$15 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let DepartmentsPipe = class DepartmentsPipe {
    transform(employees, args) {
        const departments = [];
        employees
            .filter(emp => emp.department)
            .forEach(emp => {
            if (departments.indexOf(emp.department) === -1) {
                departments.push(emp.department);
            }
        });
        return departments.sort();
    }
};
DepartmentsPipe = __decorate$15([
    Pipe({
        name: 'departments'
    })
], DepartmentsPipe);

var __decorate$16 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let EmployeeByDnPipe = class EmployeeByDnPipe {
    transform(employees, dn) {
        return employees
            .find(emp => emp.distinguishedName.toLowerCase() === dn.toLowerCase());
    }
};
EmployeeByDnPipe = __decorate$16([
    Pipe({
        name: 'employeeByDn'
    })
], EmployeeByDnPipe);

var __decorate$17 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let EmployeePhotoUrlPipe = class EmployeePhotoUrlPipe {
    transform(employee, photos) {
        if (!photos) {
            return null;
        }
        let photo;
        // Try to match by employeeNumber, accountName, or title
        photos
            .filter(pic => (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
            (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
            (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase()))
            .forEach(pic => photo = pic);
        if (!photo) {
            console.log(`No photo match for ${employee.displayName}`);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    }
};
EmployeePhotoUrlPipe = __decorate$17([
    Pipe({
        name: 'employeePhotoUrl'
    })
], EmployeePhotoUrlPipe);

var __decorate$18 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let EmployeesWithPropertyValuePipe = class EmployeesWithPropertyValuePipe {
    transform(employees, propertyName, propertyValue) {
        return employees
            .filter(emp => emp[propertyName] && emp[propertyName] === propertyValue);
    }
};
EmployeesWithPropertyValuePipe = __decorate$18([
    Pipe({
        name: 'employeesWithPropertyValue'
    })
], EmployeesWithPropertyValuePipe);

var __decorate$19 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let FilterEmployeesPipe = class FilterEmployeesPipe {
    transform(employees, filter) {
        return filter ?
            employees
                .filter(emp => emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1) :
            employees;
    }
};
FilterEmployeesPipe = __decorate$19([
    Pipe({
        name: 'filterEmployees'
    })
], FilterEmployeesPipe);

var __decorate$20 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let IsMemberOfPipe = class IsMemberOfPipe {
    transform(employee, groupName) {
        return employee.memberOf &&
            (employee.memberOf.find(m => m.toLowerCase().indexOf(groupName.toLowerCase()) !== -1) !== undefined);
    }
};
IsMemberOfPipe = __decorate$20([
    Pipe({
        name: 'isMemberOf'
    })
], IsMemberOfPipe);

var __decorate$21 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let SortEmployeesPipe = class SortEmployeesPipe {
    transform(employees, sortBy, dataType, reverse) {
        return this.getSorted(employees, sortBy ? sortBy : 'displayName', dataType ? dataType : 'string', reverse ? reverse : false);
    }
    getSorted(employees, sortBy, dataType, reverse) {
        const sorted = employees
            .sort((a, b) => {
            let valA, valB;
            switch (dataType.toLowerCase()) {
                case 'string':
                    valA = a[sortBy] ? a[sortBy].toString().toLowerCase() : null;
                    valB = b[sortBy] ? b[sortBy].toString().toLowerCase() : null;
                    break;
                case 'number':
                    valA = a[sortBy] ? +a[sortBy] : null;
                    valB = b[sortBy] ? +b[sortBy] : null;
                    break;
                case 'date':
                    valA = a[sortBy] ? a[sortBy] : null;
                    valB = b[sortBy] ? b[sortBy] : null;
                    break;
            }
            if (valA < valB) {
                return -1;
            }
            if (valA > valB) {
                return 1;
            }
            return 0;
        });
        return reverse ? sorted.reverse() : sorted;
    }
};
SortEmployeesPipe = __decorate$21([
    Pipe({
        name: 'sortEmployees'
    })
], SortEmployeesPipe);

var __decorate$13 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$12 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$9 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
// Services
// Pipes
//#endregion
let EmployeeModule = EmployeeModule_1 = class EmployeeModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(employeeConfig) {
        return {
            ngModule: EmployeeModule_1,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    }
};
EmployeeModule = EmployeeModule_1 = __decorate$13([
    NgModule({
        imports: [CommonModule],
        declarations: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ],
        exports: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ]
    }),
    __param$9(0, Optional()), __param$9(0, SkipSelf()),
    __metadata$12("design:paramtypes", [EmployeeModule])
], EmployeeModule);
var EmployeeModule_1;

var __decorate$23 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let SharePointPhotoUrlPipe = class SharePointPhotoUrlPipe {
    transform(photo) {
        return photo.ows_EncodedAbsUrl;
    }
};
SharePointPhotoUrlPipe = __decorate$23([
    Pipe({
        name: 'sharePointPhotoUrl'
    })
], SharePointPhotoUrlPipe);

var __decorate$24 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let SharePointUrlPipe = class SharePointUrlPipe {
    transform(url) {
        return url !== null ? url.split(',')[0] : null;
    }
};
SharePointUrlPipe = __decorate$24([
    Pipe({
        name: 'sharePointUrl'
    })
], SharePointUrlPipe);

var __decorate$22 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$14 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param$11 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
//#region Imports
// Services
// Pipes
//#endregion
let SharePointModule = SharePointModule_1 = class SharePointModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(sharePointConfig) {
        return {
            ngModule: SharePointModule_1,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    }
};
SharePointModule = SharePointModule_1 = __decorate$22([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ],
        exports: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ]
    }),
    __param$11(0, Optional()), __param$11(0, SkipSelf()),
    __metadata$14("design:paramtypes", [SharePointModule])
], SharePointModule);
var SharePointModule_1;

/**
 * Generated bundle index. Do not edit.
 */

export { DialogComponent as ɵa, AuthenticationModule, AuthenticationServiceConfig, AuthenticationService, LoginComponent, LoginFormComponent, DialogModule, ConfirmationDialogMode, ConfirmationDialogComponent, InputDialogComponent, MessageDialogComponent, EmailModule, EmailServiceConfig, EmailService, EmployeeModule, EmployeeServiceConfig, EmployeeService, DepartmentsPipe, EmployeeByDnPipe, EmployeePhotoUrlPipe, EmployeesWithPropertyValuePipe, FilterEmployeesPipe, IsMemberOfPipe, SortEmployeesPipe, SharePointModule, SharePointServiceConfig, SharePointService, SharePointPhotoUrlPipe, SharePointUrlPipe };
//# sourceMappingURL=ngx-lib.js.map
