import core, { Component, EventEmitter, Inject, Injectable, Input, NgModule, Optional, Output, Pipe, SkipSelf } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatButtonModule, MatCheckboxModule, MatDialog, MatDialogModule, MatDialogRef, MatInputModule, MatProgressBarModule, MatProgressSpinnerModule, MatSelectModule, MatTooltipModule } from '@angular/material';
import { HttpClient } from '@angular/common/http';
import http$1 from '@angular/http';
import Observable, { Observable as Observable$1 } from 'rxjs/Observable';
import 'rxjs/add/observable/of';
var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));
var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$1 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var DialogComponent = (function () {
    function DialogComponent() {
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
        this.mode = ConfirmationDialogMode.OkCancel;
    }
    DialogComponent.prototype.ngOnInit = function () {
        if (this.data) {
            this.title = this.data.title || null;
            this.message = this.data.message || null;
            this.checkboxMessage = this.data.checkboxMessage || null;
            this.placeholder = this.data.placeholder || null;
            this.mode = this.data.mode || ConfirmationDialogMode.OkCancel;
        }
    };
    DialogComponent.prototype.close = function () {
        var data;
        switch (this.dialogType) {
            case 'message':
                data = this.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case 'input':
                data = this.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case 'confirmation':
                data = this.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    };
    DialogComponent.prototype.cancel = function () {
        var data;
        if (this.dialogType === 'confirmation') {
            data = this.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    };
    return DialogComponent;
}());
__decorate$2([
    Input(),
    __metadata$1("design:type", String)
], DialogComponent.prototype, "dialogType", void 0);
__decorate$2([
    Input(),
    __metadata$1("design:type", Object)
], DialogComponent.prototype, "data", void 0);
__decorate$2([
    Output(),
    __metadata$1("design:type", Object)
], DialogComponent.prototype, "closed", void 0);
DialogComponent = __decorate$2([
    Component({
        selector: 'cp-dialog',
        template: "\n      <h2 *ngIf=\"title\" mat-dialog-title [innerHTML]=\"title\"></h2>\n\n      <mat-dialog-content>\n          <div *ngIf=\"message\" [innerHTML]=\"message\"></div>\n\n          <mat-form-field *ngIf=\"dialogType === 'input'\">\n              <textarea matInput [placeholder]=\"placeholder\" [(ngModel)]=\"userInput\"></textarea>\n          </mat-form-field>\n\n          <div id=\"checkbox\" *ngIf=\"checkboxMessage\">\n              <mat-checkbox [(ngModel)]=\"checkboxValue\">\n                  <span [innerHTML]=\"checkboxMessage\"></span>\n              </mat-checkbox>\n          </div>\n      </mat-dialog-content>\n\n      <mat-dialog-actions>\n          <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === 'input' && !userInput\">\n              <span [ngSwitch]=\"mode\">\n                  <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span>\n                  <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span>\n                  <span *ngSwitchDefault>OK</span>\n              </span>\n          </button>\n          <button *ngIf=\"dialogType !== 'message'\" mat-raised-button (click)=\"cancel()\">\n              <span [ngSwitch]=\"mode\">\n                  <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span>\n                  <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span>\n                  <span *ngSwitchDefault>Cancel</span>\n              </span>\n          </button>\n      </mat-dialog-actions>\n    ",
        styles: ["\n      mat-form-field {\n          margin-top: 2em;\n          width: 100%;\n      }\n\n      #checkbox {\n          margin: 2em 0;\n      }\n    "]
    })
], DialogComponent);
var __decorate$3 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$2 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$1 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
var ConfirmationDialogComponent = (function () {
    function ConfirmationDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    return ConfirmationDialogComponent;
}());
ConfirmationDialogComponent = __decorate$3([
    Component({
        selector: 'cp-confirmation-dialog',
        template: "\n    <cp-dialog\n      [data]=\"data\"\n      [dialogType]=\"'confirmation'\"\n      (closed)=\"dialogRef.close($event)\">\n    </cp-dialog>\n  "
    }),
    __param$1(1, Inject(MAT_DIALOG_DATA)),
    __metadata$2("design:paramtypes", [MatDialogRef, Object])
], ConfirmationDialogComponent);
var __decorate$4 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$3 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$2 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
var InputDialogComponent = (function () {
    function InputDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    return InputDialogComponent;
}());
InputDialogComponent = __decorate$4([
    Component({
        selector: 'cp-input-dialog',
        template: "\n      <cp-dialog\n        [data]=\"data\"\n        [dialogType]=\"'input'\"\n        (closed)=\"dialogRef.close($event)\">\n      </cp-dialog>\n    "
    }),
    __param$2(1, Inject(MAT_DIALOG_DATA)),
    __metadata$3("design:paramtypes", [MatDialogRef, Object])
], InputDialogComponent);
var __decorate$5 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$4 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$3 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
var MessageDialogComponent = (function () {
    function MessageDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    return MessageDialogComponent;
}());
MessageDialogComponent = __decorate$5([
    Component({
        selector: 'cp-message-dialog',
        template: "\n      <cp-dialog\n        [data]=\"data\"\n        [dialogType]=\"'message'\"\n        (closed)=\"dialogRef.close($event)\">\n      </cp-dialog>\n    "
    }),
    __param$3(1, Inject(MAT_DIALOG_DATA)),
    __metadata$4("design:paramtypes", [MatDialogRef, Object])
], MessageDialogComponent);
var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
//#region Imports
// Components
//#endregion
var DialogModule = (function () {
    function DialogModule() {
    }
    return DialogModule;
}());
DialogModule = __decorate$1([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatInputModule,
            MatDialogModule
        ],
        declarations: [
            DialogComponent,
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        exports: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        entryComponents: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ]
    })
], DialogModule);
var AuthenticationServiceConfig = (function () {
    function AuthenticationServiceConfig() {
    }
    return AuthenticationServiceConfig;
}());
var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};
var __extends = (commonjsGlobal && commonjsGlobal.__extends) || function (d, b) {
    for (var p in b)
        if (b.hasOwnProperty(p))
            d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var __decorate$7 = (commonjsGlobal && commonjsGlobal.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$6 = (commonjsGlobal && commonjsGlobal.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$5 = (commonjsGlobal && commonjsGlobal.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
var AuthConfigConsts = (function () {
    function AuthConfigConsts() {
    }
    return AuthConfigConsts;
}());
AuthConfigConsts.DEFAULT_TOKEN_NAME = 'token';
AuthConfigConsts.DEFAULT_HEADER_NAME = 'Authorization';
AuthConfigConsts.HEADER_PREFIX_BEARER = 'Bearer ';
var AuthConfigDefaults = {
    headerName: AuthConfigConsts.DEFAULT_HEADER_NAME,
    headerPrefix: null,
    tokenName: AuthConfigConsts.DEFAULT_TOKEN_NAME,
    tokenGetter: function () { return localStorage.getItem(AuthConfigDefaults.tokenName); },
    noJwtError: false,
    noClientCheck: false,
    globalHeaders: [],
    noTokenScheme: false
};
/**
 * Sets up the authentication configuration.
 */
var AuthConfig = (function () {
    function AuthConfig(config) {
        config = config || {};
        this._config = objectAssign({}, AuthConfigDefaults, config);
        if (this._config.headerPrefix) {
            this._config.headerPrefix += ' ';
        }
        else if (this._config.noTokenScheme) {
            this._config.headerPrefix = '';
        }
        else {
            this._config.headerPrefix = AuthConfigConsts.HEADER_PREFIX_BEARER;
        }
        if (config.tokenName && !config.tokenGetter) {
            this._config.tokenGetter = function () { return localStorage.getItem(config.tokenName); };
        }
    }
    AuthConfig.prototype.getConfig = function () {
        return this._config;
    };
    return AuthConfig;
}());
var AuthHttpError = (function (_super) {
    __extends(AuthHttpError, _super);
    function AuthHttpError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return AuthHttpError;
}(Error));
/**
 * Allows for explicit authenticated HTTP requests.
 */
var AuthHttp = (function () {
    function AuthHttp(options, http$$1, defOpts) {
        var _this = this;
        this.http = http$$1;
        this.defOpts = defOpts;
        this.config = options.getConfig();
        this.tokenStream = new Observable.Observable(function (obs) {
            obs.next(_this.config.tokenGetter());
        });
    }
    AuthHttp.prototype.mergeOptions = function (providedOpts, defaultOpts) {
        var newOptions = defaultOpts || new http$1.RequestOptions();
        if (this.config.globalHeaders) {
            this.setGlobalHeaders(this.config.globalHeaders, providedOpts);
        }
        newOptions = newOptions.merge(new http$1.RequestOptions(providedOpts));
        return newOptions;
    };
    AuthHttp.prototype.requestHelper = function (requestArgs, additionalOptions) {
        var options = new http$1.RequestOptions(requestArgs);
        if (additionalOptions) {
            options = options.merge(additionalOptions);
        }
        return this.request(new http$1.Request(this.mergeOptions(options, this.defOpts)));
    };
    AuthHttp.prototype.requestWithToken = function (req, token) {
        if (!this.config.noClientCheck && !tokenNotExpired(undefined, token)) {
            if (!this.config.noJwtError) {
                return new Observable.Observable(function (obs) {
                    obs.error(new AuthHttpError('No JWT present or has expired'));
                });
            }
        }
        else {
            req.headers.set(this.config.headerName, this.config.headerPrefix + token);
        }
        return this.http.request(req);
    };
    AuthHttp.prototype.setGlobalHeaders = function (headers, request) {
        if (!request.headers) {
            request.headers = new http$1.Headers();
        }
        headers.forEach(function (header) {
            var key = Object.keys(header)[0];
            var headerValue = header[key];
            request.headers.set(key, headerValue);
        });
    };
    AuthHttp.prototype.request = function (url, options) {
        var _this = this;
        if (typeof url === 'string') {
            return this.get(url, options); // Recursion: transform url from String to Request
        }
        // else if ( ! url instanceof Request ) {
        //   throw new Error('First argument must be a url string or Request instance.');
        // }
        // from this point url is always an instance of Request;
        var req = url;
        // Create a cold observable and load the token just in time
        return Observable.Observable.defer(function () {
            var token = _this.config.tokenGetter();
            if (token instanceof Promise) {
                return Observable.Observable.fromPromise(token).mergeMap(function (jwtToken) { return _this.requestWithToken(req, jwtToken); });
            }
            else {
                return _this.requestWithToken(req, token);
            }
        });
    };
    AuthHttp.prototype.get = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Get, url: url }, options);
    };
    AuthHttp.prototype.post = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Post, url: url }, options);
    };
    AuthHttp.prototype.put = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Put, url: url }, options);
    };
    AuthHttp.prototype.delete = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Delete, url: url }, options);
    };
    AuthHttp.prototype.patch = function (url, body, options) {
        return this.requestHelper({ body: body, method: http$1.RequestMethod.Patch, url: url }, options);
    };
    AuthHttp.prototype.head = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Head, url: url }, options);
    };
    AuthHttp.prototype.options = function (url, options) {
        return this.requestHelper({ body: '', method: http$1.RequestMethod.Options, url: url }, options);
    };
    return AuthHttp;
}());
AuthHttp = __decorate$7([
    core.Injectable(),
    __metadata$6("design:paramtypes", [AuthConfig, http$1.Http, http$1.RequestOptions])
], AuthHttp);
/**
 * Helper class to decode and find JWT expiration.
 */
var JwtHelper = (function () {
    function JwtHelper() {
    }
    JwtHelper.prototype.urlBase64Decode = function (str) {
        var output = str.replace(/-/g, '+').replace(/_/g, '/');
        switch (output.length % 4) {
            case 0: {
                break;
            }
            case 2: {
                output += '==';
                break;
            }
            case 3: {
                output += '=';
                break;
            }
            default: {
                throw 'Illegal base64url string!';
            }
        }
        return this.b64DecodeUnicode(output);
    };
    // credits for decoder goes to https://github.com/atk
    JwtHelper.prototype.b64decode = function (str) {
        var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
        var output = '';
        str = String(str).replace(/=+$/, '');
        if (str.length % 4 == 1) {
            throw new Error("'atob' failed: The string to be decoded is not correctly encoded.");
        }
        for (
        // initialize result and counters
        var bc = 0, bs = void 0, buffer = void 0, idx = 0; 
        // get next character
        buffer = str.charAt(idx++); 
        // character found in table? initialize bit storage and add its ascii value;
        ~buffer && (bs = bc % 4 ? bs * 64 + buffer : buffer, bc++ % 4) ? output += String.fromCharCode(255 & bs >> (-2 * bc & 6)) : 0) {
            // try to find character in table (0-63, not found => -1)
            buffer = chars.indexOf(buffer);
        }
        return output;
    };
    // https://developer.mozilla.org/en/docs/Web/API/WindowBase64/Base64_encoding_and_decoding#The_Unicode_Problem
    JwtHelper.prototype.b64DecodeUnicode = function (str) {
        return decodeURIComponent(Array.prototype.map.call(this.b64decode(str), function (c) {
            return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
        }).join(''));
    };
    JwtHelper.prototype.decodeToken = function (token) {
        var parts = token.split('.');
        if (parts.length !== 3) {
            throw new Error('JWT must have 3 parts');
        }
        var decoded = this.urlBase64Decode(parts[1]);
        if (!decoded) {
            throw new Error('Cannot decode the token');
        }
        return JSON.parse(decoded);
    };
    JwtHelper.prototype.getTokenExpirationDate = function (token) {
        var decoded;
        decoded = this.decodeToken(token);
        if (!decoded.hasOwnProperty('exp')) {
            return null;
        }
        var date = new Date(0); // The 0 here is the key, which sets the date to the epoch
        date.setUTCSeconds(decoded.exp);
        return date;
    };
    JwtHelper.prototype.isTokenExpired = function (token, offsetSeconds) {
        var date = this.getTokenExpirationDate(token);
        offsetSeconds = offsetSeconds || 0;
        if (date == null) {
            return false;
        }
        // Token expired?
        return !(date.valueOf() > (new Date().valueOf() + (offsetSeconds * 1000)));
    };
    return JwtHelper;
}());
var JwtHelper_1 = JwtHelper;
/**
 * Checks for presence of token and that token hasn't expired.
 * For use with the @CanActivate router decorator and NgIf
 */
function tokenNotExpired(tokenName, jwt) {
    if (tokenName === void 0) {
        tokenName = AuthConfigConsts.DEFAULT_TOKEN_NAME;
    }
    var token = jwt || localStorage.getItem(tokenName);
    var jwtHelper = new JwtHelper();
    return token != null && !jwtHelper.isTokenExpired(token);
}
var AUTH_PROVIDERS = [
    {
        provide: AuthHttp,
        deps: [http$1.Http, http$1.RequestOptions],
        useFactory: function (http$$1, options) {
            return new AuthHttp(new AuthConfig(), http$$1, options);
        }
    }
];
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;
function toObject(val) {
    if (val === null || val === undefined) {
        throw new TypeError('Object.assign cannot be called with null or undefined');
    }
    return Object(val);
}
function objectAssign(target) {
    var source = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        source[_i - 1] = arguments[_i];
    }
    var from;
    var to = toObject(target);
    var symbols;
    for (var s = 1; s < arguments.length; s++) {
        from = Object(arguments[s]);
        for (var key in from) {
            if (hasOwnProperty.call(from, key)) {
                to[key] = from[key];
            }
        }
        if (Object.getOwnPropertySymbols) {
            symbols = Object.getOwnPropertySymbols(from);
            for (var i = 0; i < symbols.length; i++) {
                if (propIsEnumerable.call(from, symbols[i])) {
                    to[symbols[i]] = from[symbols[i]];
                }
            }
        }
    }
    return to;
}
/**
 * Module for angular2-jwt
 * @experimental
 */
var AuthModule = AuthModule_1 = (function () {
    function AuthModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthModule is already loaded. Import it in the AppModule only');
        }
    }
    AuthModule.forRoot = function (config) {
        return {
            ngModule: AuthModule_1,
            providers: [
                { provide: AuthConfig, useValue: config }
            ]
        };
    };
    return AuthModule;
}());
AuthModule = AuthModule_1 = __decorate$7([
    core.NgModule({
        imports: [http$1.HttpModule],
        providers: [AuthHttp, JwtHelper]
    }),
    __param$5(0, core.Optional()), __param$5(0, core.SkipSelf()),
    __metadata$6("design:paramtypes", [AuthModule])
], AuthModule);
var AuthModule_1;
var SharePointServiceConfig = (function () {
    function SharePointServiceConfig() {
    }
    return SharePointServiceConfig;
}());
var __decorate$8 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$7 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$6 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
//#endregion
var SharePointService = (function () {
    //#endregion
    function SharePointService(config, http$$1) {
        this.http = http$$1;
        this.sharePointApiUrl = config.sharePointApiUrl;
    }
    //#region Utilities
    SharePointService.prototype.getListItems = function (list) {
        return this.http.post(this.sharePointApiUrl, list);
    };
    SharePointService.prototype.getListItemsSimple = function (list, view, site, limit) {
        return this.http.get(this.sharePointApiUrl + "/" + list + "/" + view + "/" + site + "/" + limit);
    };
    SharePointService.prototype.getPeople = function (storePeople) {
        var _this = this;
        // Do we already have people stored locally?
        if (this.people) {
            return Observable$1.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(this.sharePointApiUrl + "/people")
                .subscribe(function (peeps) { return _this.people = peeps; });
        }
        return this.http.get(this.sharePointApiUrl + "/people");
    };
    SharePointService.prototype.getPhotos = function (storePhotos) {
        var _this = this;
        // Do we already have photos stored locally?
        if (this.photos) {
            return Observable$1.of(this.photos);
        }
        var spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay'
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.sharePointApiUrl, spList)
                .subscribe(function (photos) { return _this.photos = photos; });
        }
        return this.http.post(this.sharePointApiUrl, spList);
    };
    SharePointService.prototype.getCustomerVisits = function () {
        var list = {
            list: 'Customer Visits',
            view: 'All Events'
        };
        return this.http.post(this.sharePointApiUrl, list);
    };
    return SharePointService;
}());
SharePointService = __decorate$8([
    Injectable(),
    __param$6(0, Optional()),
    __metadata$7("design:paramtypes", [SharePointServiceConfig,
        HttpClient])
], SharePointService);
var __decorate$6 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$5 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$4 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
//#endregion
var AuthenticationService = (function () {
    //#endregion
    //#region Lifecycle
    function AuthenticationService(config, http$$1, sharePointService) {
        this.http = http$$1;
        this.sharePointService = sharePointService;
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        this.authenticating = false;
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    AuthenticationService.prototype.login = function (username, password, adminGroup) {
        var _this = this;
        var today = new Date();
        var expiration = new Date().setFullYear(today.getFullYear() + 10);
        var request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(function (token) { return _this.validateUser(token); }, function (err) {
            _this.authenticating = false;
            _this.authenticatingChanged.emit(_this.authenticating);
        });
    };
    AuthenticationService.prototype.logout = function () {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    };
    AuthenticationService.prototype.validateUser = function (token) {
        if (!token) {
            return;
        }
        var jwtHelper = new JwtHelper_1();
        var decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem('token', token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    };
    AuthenticationService.prototype.getPhoto = function () {
        var _this = this;
        this.sharePointService.getPhotos()
            .subscribe(function (photos) {
            // The user may have been logged out by the time the photos came back
            if (!_this.authenticatedUser || !_this.authenticatedUser.employeeNumber) {
                return;
            }
            var photo = photos.find(function (pic) { return +pic.ows_EmployeeNumber === +_this.authenticatedUser.employeeNumber; });
            if (photo) {
                _this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    };
    AuthenticationService.prototype.checkForExistingToken = function () {
        if (localStorage.getItem('token')) {
            this.validateUser(localStorage.getItem('token'));
        }
    };
    return AuthenticationService;
}());
__decorate$6([
    Output(),
    __metadata$5("design:type", Object)
], AuthenticationService.prototype, "authenticatedChanged", void 0);
__decorate$6([
    Output(),
    __metadata$5("design:type", Object)
], AuthenticationService.prototype, "authenticatingChanged", void 0);
AuthenticationService = __decorate$6([
    Injectable(),
    __param$4(0, Optional()),
    __metadata$5("design:paramtypes", [AuthenticationServiceConfig,
        HttpClient,
        SharePointService])
], AuthenticationService);
var __decorate$10 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$9 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var LoginFormComponent = (function () {
    function LoginFormComponent(dialogRef, sharePointService, authenticationService) {
        this.dialogRef = dialogRef;
        this.sharePointService = sharePointService;
        this.authenticationService = authenticationService;
    }
    LoginFormComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.authenticationService.authenticatedChanged
            .subscribe(function (authenticated) {
            if (authenticated) {
                _this.dialogRef.close();
            }
        });
    };
    LoginFormComponent.prototype.authenticate = function () {
        if (!this.sharePointService || !this.username || !this.password) {
            return;
        }
        this.authenticationService.login(this.username, this.password);
    };
    return LoginFormComponent;
}());
LoginFormComponent = __decorate$10([
    Component({
        selector: 'cp-login-form',
        template: "\n    <h2 mat-dialog-title>\n      <span *ngIf=\"!authenticationService.authenticating\">Login</span>\n      <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span>\n    </h2>\n\n    <mat-dialog-content [class.loginError]=\"loginError\">\n      <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\">\n        <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner>\n      </div>\n\n      <div *ngIf=\"!authenticationService.authenticating\">\n        <div>\n          <mat-form-field>\n            <input matInput placeholder=\"Username\" [(ngModel)]=\"username\" name=\"username\" required (keyup.enter)=\"authenticate()\">\n          </mat-form-field>\n        </div>\n\n        <div>\n          <mat-form-field>\n            <input matInput type=\"password\" placeholder=\"Password\" [(ngModel)]=\"password\" name=\"password\" required (keyup.enter)=\"authenticate()\">\n          </mat-form-field>\n        </div>\n      </div>\n\n      <div *ngIf=\"!authenticationService.authenticating && loginError\" class=\"alert alert-danger\">\n        Bad username or password\n      </div>\n    </mat-dialog-content>\n\n    <mat-dialog-actions *ngIf=\"!authenticationService.authenticating\">\n      <button type=\"button\" mat-raised-button (click)=\"authenticate()\">OK</button>\n      <button type=\"button\" mat-button (click)=\"dialogRef.close()\">Cancel</button>\n    </mat-dialog-actions>\n  ",
        styles: ["\n    #spinner {\n        width: 100%;\n        height: 100%;\n        display: -webkit-box;\n        display: -ms-flexbox;\n        display: flex;\n        -webkit-box-pack: center;\n            -ms-flex-pack: center;\n                justify-content: center;\n        -webkit-box-align: center;\n            -ms-flex-align: center;\n                align-items: center;\n    }\n\n    mat-dialog-content {\n        height: 150px;\n    }\n\n    mat-dialog-content.loginError {\n        height: 200px;\n    }\n  "]
    }),
    __metadata$9("design:paramtypes", [MatDialogRef,
        SharePointService,
        AuthenticationService])
], LoginFormComponent);
var __decorate$9 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$8 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var LoginComponent = (function () {
    function LoginComponent(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    LoginComponent.prototype.ngOnInit = function () {
    };
    LoginComponent.prototype.login = function () {
        this.dialog.open(LoginFormComponent);
    };
    LoginComponent.prototype.confirmLogout = function () {
        var _this = this;
        var dialogRef = this.dialog.open(ConfirmationDialogComponent, {
            data: { message: "Are you sure you want to logout?" }
        });
        dialogRef.afterClosed().subscribe(function (result) {
            if (result) {
                _this.authenticationService.logout();
            }
        });
    };
    return LoginComponent;
}());
LoginComponent = __decorate$9([
    Component({
        selector: 'cp-login',
        template: "\n    <div id=\"user-id\">\n      <i id=\"unauthenticated-user-image\" *ngIf=\"!authenticationService.authenticated\"\n        class=\"fa fa-user-circle\"\n        [class.fa-spin]=\"authenticationService.authenticating\"\n        aria-hidden=\"true\"\n        title=\"Login\"\n        (click)=\"login()\"></i>\n\n      <img id=\"authenticated-user-image\" *ngIf=\"authenticationService.authenticated && authenticationService.authenticatedUser.photoUrl\"\n        [src]=\"authenticationService.authenticatedUser.photoUrl\"\n        title=\"Logout\"\n        (click)=\"confirmLogout()\" />\n\n      <div id=\"user-name\" *ngIf=\"authenticationService.authenticated\">\n        {{ authenticationService.authenticatedUser.displayName }}\n      </div>\n    </div>\n  ",
        styles: ["\n    #user-id {\n        display: -webkit-box;\n        display: -ms-flexbox;\n        display: flex;\n        height: 2em;\n        padding: .3em;\n        font-family: Verdana, Geneva, Tahoma, sans-serif;\n    }\n\n    .fa {\n        font-size: 2em;\n    }\n\n    img {\n        border-radius: 100%;\n        width: 2em;\n        height: 2em;\n    }\n\n    #user-id > div {\n        display: -webkit-box;\n        display: -ms-flexbox;\n        display: flex;\n        -webkit-box-align: center;\n            -ms-flex-align: center;\n                align-items: center;\n        height: 100%;\n        margin-left: .75em;\n        font-size: 1.15em;\n    }\n  "]
    }),
    __metadata$8("design:paramtypes", [MatDialog,
        AuthenticationService])
], LoginComponent);
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
// Modules
// Services
// Components
//#endregion
var AuthenticationModule = AuthenticationModule_1 = (function () {
    function AuthenticationModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    AuthenticationModule.forRoot = function (authenticationConfig) {
        return {
            ngModule: AuthenticationModule_1,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    };
    return AuthenticationModule;
}());
AuthenticationModule = AuthenticationModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatInputModule,
            MatProgressBarModule,
            MatProgressSpinnerModule,
            MatTooltipModule,
            MatSelectModule,
            DialogModule
        ],
        declarations: [
            LoginComponent,
            LoginFormComponent
        ],
        exports: [
            LoginComponent,
            LoginFormComponent
        ],
        providers: [],
        entryComponents: [
            LoginFormComponent
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf()),
    __metadata("design:paramtypes", [AuthenticationModule])
], AuthenticationModule);
var AuthenticationModule_1;
var EmailServiceConfig = (function () {
    function EmailServiceConfig() {
    }
    return EmailServiceConfig;
}());
var __decorate$12 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$11 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$8 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
//#endregion
var EmailService = (function () {
    function EmailService(config, http$$1) {
        this.http = http$$1;
        this.emailServiceConfig = config;
    }
    EmailService.prototype.send = function (email) {
        var dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    };
    return EmailService;
}());
EmailService = __decorate$12([
    Injectable(),
    __param$8(0, Optional()),
    __metadata$11("design:paramtypes", [EmailServiceConfig,
        HttpClient])
], EmailService);
var __decorate$11 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$10 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$7 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
// Services
//#endregion
var EmailModule = EmailModule_1 = (function () {
    function EmailModule(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    EmailModule.forRoot = function (emailConfig) {
        return {
            ngModule: EmailModule_1,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    };
    return EmailModule;
}());
EmailModule = EmailModule_1 = __decorate$11([
    NgModule({
        imports: [CommonModule],
        declarations: [],
        exports: []
    }),
    __param$7(0, Optional()), __param$7(0, SkipSelf()),
    __metadata$10("design:paramtypes", [EmailModule])
], EmailModule);
var EmailModule_1;
var EmployeeServiceConfig = (function () {
    function EmployeeServiceConfig() {
    }
    return EmployeeServiceConfig;
}());
var __decorate$14 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$13 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$10 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
//#endregion
var EmployeeService = (function () {
    //#endregion
    //#region Lifecycle
    function EmployeeService(config, http$$1) {
        this.http = http$$1;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    EmployeeService.prototype.getEmployees = function (storeEmployees) {
        var _this = this;
        // Do we already have employees stored locally?
        if (this.employees) {
            return Observable$1.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(this.employeeApiUrl)
                .subscribe(function (emps) { return _this.employees = emps; });
        }
        return this.http.get(this.employeeApiUrl);
    };
    EmployeeService.prototype.getEmployee = function (sAMAccountName) {
        return this.http.get(this.employeeApiUrl + "/name/" + sAMAccountName);
    };
    return EmployeeService;
}());
EmployeeService = __decorate$14([
    Injectable(),
    __param$10(0, Optional()),
    __metadata$13("design:paramtypes", [EmployeeServiceConfig,
        HttpClient])
], EmployeeService);
var __decorate$15 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var DepartmentsPipe = (function () {
    function DepartmentsPipe() {
    }
    DepartmentsPipe.prototype.transform = function (employees, args) {
        var departments = [];
        employees
            .filter(function (emp) { return emp.department; })
            .forEach(function (emp) {
            if (departments.indexOf(emp.department) === -1) {
                departments.push(emp.department);
            }
        });
        return departments.sort();
    };
    return DepartmentsPipe;
}());
DepartmentsPipe = __decorate$15([
    Pipe({
        name: 'departments'
    })
], DepartmentsPipe);
var __decorate$16 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var EmployeeByDnPipe = (function () {
    function EmployeeByDnPipe() {
    }
    EmployeeByDnPipe.prototype.transform = function (employees, dn) {
        return employees
            .find(function (emp) { return emp.distinguishedName.toLowerCase() === dn.toLowerCase(); });
    };
    return EmployeeByDnPipe;
}());
EmployeeByDnPipe = __decorate$16([
    Pipe({
        name: 'employeeByDn'
    })
], EmployeeByDnPipe);
var __decorate$17 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var EmployeePhotoUrlPipe = (function () {
    function EmployeePhotoUrlPipe() {
    }
    EmployeePhotoUrlPipe.prototype.transform = function (employee, photos) {
        if (!photos) {
            return null;
        }
        var photo;
        // Try to match by employeeNumber, accountName, or title
        photos
            .filter(function (pic) { return (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
            (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
            (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase()); })
            .forEach(function (pic) { return photo = pic; });
        if (!photo) {
            console.log("No photo match for " + employee.displayName);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    };
    return EmployeePhotoUrlPipe;
}());
EmployeePhotoUrlPipe = __decorate$17([
    Pipe({
        name: 'employeePhotoUrl'
    })
], EmployeePhotoUrlPipe);
var __decorate$18 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var EmployeesWithPropertyValuePipe = (function () {
    function EmployeesWithPropertyValuePipe() {
    }
    EmployeesWithPropertyValuePipe.prototype.transform = function (employees, propertyName, propertyValue) {
        return employees
            .filter(function (emp) { return emp[propertyName] && emp[propertyName] === propertyValue; });
    };
    return EmployeesWithPropertyValuePipe;
}());
EmployeesWithPropertyValuePipe = __decorate$18([
    Pipe({
        name: 'employeesWithPropertyValue'
    })
], EmployeesWithPropertyValuePipe);
var __decorate$19 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var FilterEmployeesPipe = (function () {
    function FilterEmployeesPipe() {
    }
    FilterEmployeesPipe.prototype.transform = function (employees, filter) {
        return filter ?
            employees
                .filter(function (emp) { return emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1; }) :
            employees;
    };
    return FilterEmployeesPipe;
}());
FilterEmployeesPipe = __decorate$19([
    Pipe({
        name: 'filterEmployees'
    })
], FilterEmployeesPipe);
var __decorate$20 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var IsMemberOfPipe = (function () {
    function IsMemberOfPipe() {
    }
    IsMemberOfPipe.prototype.transform = function (employee, groupName) {
        return employee.memberOf &&
            (employee.memberOf.find(function (m) { return m.toLowerCase().indexOf(groupName.toLowerCase()) !== -1; }) !== undefined);
    };
    return IsMemberOfPipe;
}());
IsMemberOfPipe = __decorate$20([
    Pipe({
        name: 'isMemberOf'
    })
], IsMemberOfPipe);
var __decorate$21 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var SortEmployeesPipe = (function () {
    function SortEmployeesPipe() {
    }
    SortEmployeesPipe.prototype.transform = function (employees, sortBy, dataType, reverse) {
        return this.getSorted(employees, sortBy ? sortBy : 'displayName', dataType ? dataType : 'string', reverse ? reverse : false);
    };
    SortEmployeesPipe.prototype.getSorted = function (employees, sortBy, dataType, reverse) {
        var sorted = employees
            .sort(function (a, b) {
            var valA, valB;
            switch (dataType.toLowerCase()) {
                case 'string':
                    valA = a[sortBy] ? a[sortBy].toString().toLowerCase() : null;
                    valB = b[sortBy] ? b[sortBy].toString().toLowerCase() : null;
                    break;
                case 'number':
                    valA = a[sortBy] ? +a[sortBy] : null;
                    valB = b[sortBy] ? +b[sortBy] : null;
                    break;
                case 'date':
                    valA = a[sortBy] ? a[sortBy] : null;
                    valB = b[sortBy] ? b[sortBy] : null;
                    break;
            }
            if (valA < valB) {
                return -1;
            }
            if (valA > valB) {
                return 1;
            }
            return 0;
        });
        return reverse ? sorted.reverse() : sorted;
    };
    return SortEmployeesPipe;
}());
SortEmployeesPipe = __decorate$21([
    Pipe({
        name: 'sortEmployees'
    })
], SortEmployeesPipe);
var __decorate$13 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$12 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$9 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
// Services
// Pipes
//#endregion
var EmployeeModule = EmployeeModule_1 = (function () {
    function EmployeeModule(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    EmployeeModule.forRoot = function (employeeConfig) {
        return {
            ngModule: EmployeeModule_1,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    };
    return EmployeeModule;
}());
EmployeeModule = EmployeeModule_1 = __decorate$13([
    NgModule({
        imports: [CommonModule],
        declarations: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ],
        exports: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ]
    }),
    __param$9(0, Optional()), __param$9(0, SkipSelf()),
    __metadata$12("design:paramtypes", [EmployeeModule])
], EmployeeModule);
var EmployeeModule_1;
var __decorate$23 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var SharePointPhotoUrlPipe = (function () {
    function SharePointPhotoUrlPipe() {
    }
    SharePointPhotoUrlPipe.prototype.transform = function (photo) {
        return photo.ows_EncodedAbsUrl;
    };
    return SharePointPhotoUrlPipe;
}());
SharePointPhotoUrlPipe = __decorate$23([
    Pipe({
        name: 'sharePointPhotoUrl'
    })
], SharePointPhotoUrlPipe);
var __decorate$24 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var SharePointUrlPipe = (function () {
    function SharePointUrlPipe() {
    }
    SharePointUrlPipe.prototype.transform = function (url) {
        return url !== null ? url.split(',')[0] : null;
    };
    return SharePointUrlPipe;
}());
SharePointUrlPipe = __decorate$24([
    Pipe({
        name: 'sharePointUrl'
    })
], SharePointUrlPipe);
var __decorate$22 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata$14 = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
var __param$11 = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
};
//#region Imports
// Services
// Pipes
//#endregion
var SharePointModule = SharePointModule_1 = (function () {
    function SharePointModule(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    SharePointModule.forRoot = function (sharePointConfig) {
        return {
            ngModule: SharePointModule_1,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    };
    return SharePointModule;
}());
SharePointModule = SharePointModule_1 = __decorate$22([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ],
        exports: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ]
    }),
    __param$11(0, Optional()), __param$11(0, SkipSelf()),
    __metadata$14("design:paramtypes", [SharePointModule])
], SharePointModule);
var SharePointModule_1;
/**
 * Generated bundle index. Do not edit.
 */
export { DialogComponent as ɵa, AuthenticationModule, AuthenticationServiceConfig, AuthenticationService, LoginComponent, LoginFormComponent, DialogModule, ConfirmationDialogMode, ConfirmationDialogComponent, InputDialogComponent, MessageDialogComponent, EmailModule, EmailServiceConfig, EmailService, EmployeeModule, EmployeeServiceConfig, EmployeeService, DepartmentsPipe, EmployeeByDnPipe, EmployeePhotoUrlPipe, EmployeesWithPropertyValuePipe, FilterEmployeesPipe, IsMemberOfPipe, SortEmployeesPipe, SharePointModule, SharePointServiceConfig, SharePointService, SharePointPhotoUrlPipe, SharePointUrlPipe };
//# sourceMappingURL=ngx-lib.js.map
